==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ca.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendari",
    "%s has published the calendar \"%s\"" : "%s ha publicat el calendari \"%s\"",
    "Too many redirects. Aborting ..." : "Massa redireccions. Avortant...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remot no ens a permès l'accés al calendari  (error HTTP {%s})",
    "Error connecting to remote server" : "S'ha produit un error al connectar al servidor remot",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error al sol·licitar el recurs al servidor remot. Es possible que estigui relacionat amb un problema amb el certificat",
    "Error requesting resource on remote server" : "Error al sol·licitar el recurs al servidor remot",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Recurs",
    "Room" : "Sala",
    "Unknown" : "Desconegut",
    "Required" : "Requerit",
    "Optional" : "Opcional",
    "Does not attend" : "No assistir",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Et trobes a una zona horaria desconeguda ({tz}), tornant a UTC",
    "Please create a calendar first." : "Si us plau, creeu un calendari primer",
    "New event" : "Esdeveniment nou",
    "CalDAV address for clients" : "Adreça CalDAV per els clients",
    "Error saving WebCal-calendar" : "Error desant el calendari WebCal",
    "WebDAV address for subscriptions" : "Adreça WebDAV per subscripcions",
    "EMail has been sent." : "S'ha enviat el correu.",
    "There was an issue while sending your EMail." : "S'ha produït un problema al enviar el correu electrònic",
    "group" : "grup",
    "Details" : "Detalls",
    "Attendees" : "Assistents",
    "Reminders" : "Recordatoris",
    "Repeating" : "Repetició",
    "When shared show full event" : "Mostrar l'esdeveniment sencer al compartir",
    "When shared show only busy" : "Mostra només ocupat al compartir",
    "When shared hide this event" : "Ocular aquest esdeveniment al compartir",
    "Confirmed" : "Confirmada",
    "Tentative" : "Temptativa",
    "Cancelled" : "S'ha cancel·lat",
    "Please add a title!" : "Si us plau, afegiu un títol!",
    "Please select a calendar!" : "Si us plau, seleccioneu un calendari!",
    "Global" : "Global",
    "None" : "Cap",
    "Every day" : "Cada dia",
    "Every week" : "Cada setmana",
    "Every month" : "Cada mes",
    "Every year" : "Cada any",
    "never" : "mai",
    "after" : "després de",
    "How about getting started by importing some calendars?" : "Què tal començar amb la importació d'alguns calendaris?",
    "At time of event" : "En el moment de l'esdeveniment",
    "5 minutes before" : "5 minuts abans",
    "10 minutes before" : "10 minuts abans",
    "15 minutes before" : "15 minuts abans",
    "30 minutes before" : "30 minuts abans",
    "1 hour before" : "1 hora abans",
    "2 hours before" : "2 hores abans",
    "Custom" : "Personalitza...",
    "Audio" : "Audio",
    "E Mail" : "Correu",
    "Pop up" : "Finestra emergent",
    "sec" : "seg",
    "min" : "min",
    "hours" : "hores",
    "days" : "dies",
    "week" : "setmana",
    "before" : "abans",
    "start" : "comença",
    "end" : "final",
    "Editing reminders of unknown type not supported." : "L'edició de recordatoris de tipus desconegut no està suportada.",
    "Week {number} of {year}" : "Setmana {number} de {year}",
    "Successfully imported" : "S'ha importat correctament",
    "Partially imported, 1 failure" : "Parcialment importat, 1 error",
    "Partially imported, {n} failures" : "Parcialment importat, {n} errors",
    "Audio alarm" : "So d'alarma",
    "Pop-up" : "Finestra emergent",
    "E-Mail" : "Correu",
    "{type} {time} before the event starts" : "{type} {time} abans que comenci l'esdeveniment",
    "{type} {time} before the event ends" : "{type} {time} abans que finalitzi l'esdeveniment",
    "{type} {time} after the event starts" : "{type} {time} després que comenci l'esdeveniment",
    "{type} {time} after the event ends" : "{type} {time} després que finalitzi l'esdeveniment",
    "{type} at the event's start" : "{type} al principi de l'esdeveniment",
    "{type} at the event's end" : "{type} al final de l'esdeveniment",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartit per {owner}",
    "Please enter a valid WebCal-URL" : "Introdueix una WebCal-URL vàlida si us plau",
    "Title of the Event" : "Títol de l'esdeveniment",
    "All day Event" : "Esdeveniment de tot el dia",
    "Delete" : "Esborra",
    "Cancel" : "Cancel·la",
    "More ..." : "Més",
    "Create" : "Crea",
    "Update" : "Actualitza",
    "Close" : "tanca",
    "Location" : "Ubicació",
    "Description" : "Descripció",
    "Event status" : "Estat de l'esdeveniment",
    "Visibility when sharing" : "Visibilitat en compartir",
    "Export" : "Exporta",
    "%s has published the calendar %s" : "%s ha publicat el calendari %s",
    "Hello," : "Hola,",
    "Click here to access it" : "Click aquí per accedir",
    "Cheers!" : "Salut!",
    "Click on the link below to access it" : "Entra a l'enllaç de sota per accedir-hi",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa d'un error (bug) de \"upstrem\", el calendari no suporta la funció \"asset pipeline\"",
    "Day" : "Dia",
    "Week" : "Setmana",
    "Month" : "Mes",
    "Today" : "Avui",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns esdeveniments d'aquest calendari contenen errors. Revisa la consola JS per a més informació.",
    "Share Calendar" : "Comparteix el calendari",
    "Shared" : "Compartit",
    "More" : "Més",
    "Edit" : "Edita",
    "Link" : "Enllaç",
    "iCal link" : "iCal link",
    "Download" : "Descàrrega",
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "can edit" : "pot editar",
    "Share link" : "Comparteix l'enllaç",
    "Public access" : "Accés públic",
    "Email link to person" : "Enllaç per correu electrónic amb la persona",
    "Send" : "Envia",
    "New Calendar" : "Calendari nou",
    "Name" : "Nom",
    "New Subscription" : "Nova subscripció",
    "Go back" : "Tornar enrere",
    "Go forward" : "Anar endavant",
    "Edit event" : "Edita l'esdeveniment",
    "Delete Event" : "Esborra l'esdeveniment",
    "Save Event" : "Desa l'esdeveniment",
    "Time" : "Hora",
    "Type" : "Tipus",
    "Relative" : "Relatiu",
    "Absolute" : "Absolut",
    "Repeat" : "Repeteix",
    "times every" : "vegades cada",
    "Add" : "Afegeix",
    "E-Mail address of attendee" : "Adreça de correu electrònic de l'assistent",
    "Please add your email address in the personal settings in order to add attendees." : "Si us plau, introduïu la vostra adreça de correu electrònic a la configuració del compte per poder afegir assistents",
    "from" : "des de",
    "to" : "a",
    "Repeat every ..." : "Repeteix cada ...",
    "end repeat ..." : "finalitza repetició ...",
    "times" : "Temps",
    "Import Calendars" : "Importa Calendaris",
    "Import canceled" : "Importació cancel·lada",
    "Analyzing calendar" : "Analitzant calendari",
    "New calendar" : "Calendari nou",
    "File is empty" : "El Fitxer està plè",
    "Import scheduled" : "Importa els programats",
    "Publish URL" : "Publica la URL",
    "Settings & import" : "Configuració & importació",
    "Skip simple event editor" : "Salta l'editor simple d'esdeveniments",
    "Show week numbers" : "Mostra el número de la setmana",
    "Import calendar" : "Importa calendari",
    "No Calendars selected for import" : "No heu sel·leccionat cap calendari per a importar ",
    "Primary CalDAV address" : "Adreça primària de caldav",
    "iOS/OS X CalDAV address" : "Adreça CalDAV per IOS/OS X"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ca.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendari",
    "%s has published the calendar »%s«" : "%s ha publicat el calendari »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Et volem informar que %s ha publicat el calendari »%s«.",
    "Open »%s«" : "Obre »%s«",
    "Cheers!" : "Salut!",
    "Recipient" : "Destinatari",
    "Too many redirects. Aborting ..." : "Massa redireccions. Avortant...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remot no ens a permès l'accés al calendari  (error HTTP {%s})",
    "Error connecting to remote server" : "S'ha produit un error al connectar al servidor remot",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error al sol·licitar el recurs al servidor remot. Es possible que estigui relacionat amb un problema amb el certificat",
    "Error requesting resource on remote server" : "Error al sol·licitar el recurs al servidor remot",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Recurs",
    "Room" : "Sala",
    "Unknown" : "Desconegut",
    "Required" : "Requerit",
    "Optional" : "Opcional",
    "Does not attend" : "No assistir",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Et trobes a una zona horaria desconeguda ({tz}), tornant a UTC",
    "Please create a calendar first." : "Si us plau, creeu un calendari primer",
    "New event" : "Esdeveniment nou",
    "CalDAV address for clients" : "Adreça CalDAV per els clients",
    "Error saving WebCal-calendar" : "Error desant el calendari WebCal",
    "WebDAV address for subscriptions" : "Adreça WebDAV per subscripcions",
    "Email has been sent." : "S'ha enviat el correu.",
    "There was an issue while sending your email." : "S'ha produït un problema al enviar el teu correu electrònic.",
    "group" : "grup",
    "Details" : "Detalls",
    "Attendees" : "Assistents",
    "Reminders" : "Recordatoris",
    "Repeating" : "Repetició",
    "When shared show full event" : "Mostrar l'esdeveniment sencer al compartir",
    "When shared show only busy" : "Mostra només ocupat al compartir",
    "When shared hide this event" : "Ocular aquest esdeveniment al compartir",
    "Confirmed" : "Confirmada",
    "Tentative" : "Temptativa",
    "Cancelled" : "S'ha cancel·lat",
    "Please add a title." : "Si us plau, afegiu un títol.",
    "Please select a calendar." : "Si us plau, seleccioneu un calendari.",
    "The event can not end before it starts." : "L'esdeveniment no pot acabar abans de començar.",
    "Global" : "Global",
    "None" : "Cap",
    "Every day" : "Cada dia",
    "Every week" : "Cada setmana",
    "Every month" : "Cada mes",
    "Every year" : "Cada any",
    "never" : "mai",
    "after" : "després de",
    "How about getting started by importing some calendars?" : "Què tal començar amb la importació d'alguns calendaris?",
    "At time of event" : "En el moment de l'esdeveniment",
    "5 minutes before" : "5 minuts abans",
    "10 minutes before" : "10 minuts abans",
    "15 minutes before" : "15 minuts abans",
    "30 minutes before" : "30 minuts abans",
    "1 hour before" : "1 hora abans",
    "2 hours before" : "2 hores abans",
    "Custom" : "Personalitza...",
    "Audio" : "Audio",
    "Email" : "Correu",
    "Pop-up" : "Finestra emergent",
    "sec" : "seg",
    "min" : "min",
    "hours" : "hores",
    "days" : "dies",
    "week" : "setmana",
    "before" : "abans",
    "start" : "comença",
    "end" : "final",
    "Editing reminders of unknown type not supported." : "L'edició de recordatoris de tipus desconegut no està suportada.",
    "Week {number} of {year}" : "Setmana {number} de {year}",
    "Successfully imported" : "S'ha importat correctament",
    "Partially imported, 1 failure" : "Parcialment importat, 1 error",
    "Partially imported, {n} failures" : "Parcialment importat, {n} errors",
    "Audio alarm" : "So d'alarma",
    "{type} {time} before the event starts" : "{type} {time} abans que comenci l'esdeveniment",
    "{type} {time} before the event ends" : "{type} {time} abans que finalitzi l'esdeveniment",
    "{type} {time} after the event starts" : "{type} {time} després que comenci l'esdeveniment",
    "{type} {time} after the event ends" : "{type} {time} després que finalitzi l'esdeveniment",
    "{type} at the event's start" : "{type} al principi de l'esdeveniment",
    "{type} at the event's end" : "{type} al final de l'esdeveniment",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartit per {owner}",
    "Please enter a valid WebCal-URL" : "Introdueix una WebCal-URL vàlida si us plau",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Error sever al webcal proxy. Contacta amb l'administrador per a més informació.",
    "Title of the Event" : "Títol de l'esdeveniment",
    "Starts" : "Comença",
    "Ends" : "Finalitza",
    "All day Event" : "Esdeveniment de tot el dia",
    "Delete" : "Esborra",
    "Cancel" : "Cancel·la",
    "More ..." : "Més",
    "Create" : "Crea",
    "Update" : "Actualitza",
    "Close" : "tanca",
    "Location" : "Ubicació",
    "Description" : "Descripció",
    "Event status" : "Estat de l'esdeveniment",
    "Visibility when sharing" : "Visibilitat en compartir",
    "Export" : "Exporta",
    "%s has published the calendar %s" : "%s ha publicat el calendari %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Et volem informar que %s ha publicat el calendari {boldstart}%s{boldend}.",
    "Click here to access it" : "Click aquí per accedir",
    "We wanted to inform you that %s has published the calendar %s." : "Et volem informar que %s ha publicat el calendari %s.",
    "Click on the link below to access it" : "Entra a l'enllaç de sota per accedir-hi",
    "Day" : "Dia",
    "Week" : "Setmana",
    "Month" : "Mes",
    "Today" : "Avui",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns esdeveniments d'aquest calendari contenen errors. Revisa la consola JS per a més informació.",
    "Share Calendar" : "Comparteix el calendari",
    "Shared" : "Compartit",
    "More" : "Més",
    "Edit" : "Edita",
    "Link" : "Enllaç",
    "iCal link" : "iCal link",
    "Download" : "Descàrrega",
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "can edit" : "pot editar",
    "Share link" : "Comparteix l'enllaç",
    "Public access" : "Accés públic",
    "Email link to person" : "Enllaç per correu electrónic amb la persona",
    "Send" : "Envia",
    "New Calendar" : "Calendari nou",
    "Name" : "Nom",
    "New Subscription" : "Nova subscripció",
    "Go back" : "Tornar enrere",
    "Go forward" : "Anar endavant",
    "Calendar does not exist" : "El calendari no existeix",
    "Maybe you got a wrong link or the calendar was unshared?" : "Potser tens un enllaç incorrecte o el s'ha descompartit el calendari?",
    "Edit event" : "Edita l'esdeveniment",
    "Delete Event" : "Esborra l'esdeveniment",
    "Save Event" : "Desa l'esdeveniment",
    "Time" : "Hora",
    "Type" : "Tipus",
    "Relative" : "Relatiu",
    "Absolute" : "Absolut",
    "Repeat" : "Repeteix",
    "times every" : "vegades cada",
    "Add" : "Afegeix",
    "Email address of attendee" : "Adreça de correu electrònic de l'assistent",
    "Please add your email address in the personal settings in order to add attendees." : "Si us plau, introduïu la vostra adreça de correu electrònic a la configuració del compte per poder afegir assistents",
    "from" : "des de",
    "to" : "a",
    "This event's repeating rule is not supported yet." : "Aquesta regla de repetició encara no està suportada.",
    "Support for advanced rules will be added with subsequent updates." : "El suport per a regles avançades serà afegit en futures actualitzacions.",
    "Reset repeating rule" : "Reinicia la regla de repetició",
    "Repeat every ..." : "Repeteix cada ...",
    "end repeat ..." : "finalitza repetició ...",
    "times" : "Temps",
    "Import Calendars" : "Importa Calendaris",
    "Import canceled" : "Importació cancel·lada",
    "Analyzing calendar" : "Analitzant calendari",
    "The file contains objects incompatible with the selected calendar" : "El fitxer conté objectes incompatibles amb el calendari escollit",
    "New calendar" : "Calendari nou",
    "File is empty" : "El Fitxer està plè",
    "Import scheduled" : "Importa els programats",
    "%s shared the calendar <strong>%s</strong> with you" : "%s ha compartit el calendar <strong>%s</strong> amb tu",
    "Embed" : "Empotra",
    "Iframe to integrate" : "Iframe per integrar",
    "Publish URL" : "Publica la URL",
    "Settings & import" : "Configuració & importació",
    "Skip simple event editor" : "Salta l'editor simple d'esdeveniments",
    "Show week numbers" : "Mostra el número de la setmana",
    "Import calendar" : "Importa calendari",
    "No Calendars selected for import" : "No heu sel·leccionat cap calendari per a importar ",
    "Primary CalDAV address" : "Adreça primària de caldav",
    "iOS/OS X CalDAV address" : "Adreça CalDAV per IOS/OS X",
    "Subscribe" : "Subscriu"
},
"nplurals=2; plural=(n != 1);");
